@@ -1,6 +1,6 @@
 /* gda-set.h
  *
- * Copyright (C) 2003 - 2008 Vivien Malerba
+ * Copyright (C) 2003 - 2009 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -117,6 +117,12 @@ struct _GdaSetClass
 	void                  (*holder_attr_changed)   (GdaSet *set, GdaHolder *holder, 
 							const gchar *attr_name, const GValue *attr_value);
 	void                  (*public_data_changed)   (GdaSet *set);
+
+	/* Padding for future expansion */
+	void (*_gda_reserved1) (void);
+	void (*_gda_reserved2) (void);
+	void (*_gda_reserved3) (void);
+	void (*_gda_reserved4) (void);
 };
 
 GType         gda_set_get_type                 (void) G_GNUC_CONST;
