@@ -52,12 +52,17 @@ struct _GdaSqlExpr {
 	GdaSqlCase      *case_s;
 
 	gchar           *cast_as;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
+
 GdaSqlExpr      *gda_sql_expr_new            (GdaSqlAnyPart *parent);
 void             gda_sql_expr_free           (GdaSqlExpr *expr);
 GdaSqlExpr      *gda_sql_expr_copy           (GdaSqlExpr *expr);
 gchar           *gda_sql_expr_serialize      (GdaSqlExpr *expr);
-void             gda_sql_expr_check_clean    (GdaSqlExpr *expr);
+void             _gda_sql_expr_check_clean   (GdaSqlExpr *expr);
 
 void             gda_sql_expr_take_select    (GdaSqlExpr *expr, GdaSqlStatement *stmt);
 
@@ -70,12 +75,17 @@ struct _GdaSqlField {
 
 	/* validity check with a connection */
 	GdaMetaTableColumn *validity_meta_table_column;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
+
 GdaSqlField     *gda_sql_field_new            (GdaSqlAnyPart *parent);
 void             gda_sql_field_free           (GdaSqlField *field);
 GdaSqlField     *gda_sql_field_copy           (GdaSqlField *field);
 gchar           *gda_sql_field_serialize      (GdaSqlField *field);
-void             gda_sql_field_check_clean    (GdaSqlField *field);
+void             _gda_sql_field_check_clean   (GdaSqlField *field);
 
 void             gda_sql_field_take_name      (GdaSqlField *field, GValue *value);
 
@@ -89,13 +99,17 @@ struct _GdaSqlTable
 
 	/* validity check with a connection */
 	GdaMetaDbObject    *validity_meta_object;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlTable     *gda_sql_table_new            (GdaSqlAnyPart *parent);
 void             gda_sql_table_free           (GdaSqlTable *table);
 GdaSqlTable     *gda_sql_table_copy           (GdaSqlTable *table);
 gchar           *gda_sql_table_serialize      (GdaSqlTable *table);
-void             gda_sql_table_check_clean    (GdaSqlTable *table);
+void             _gda_sql_table_check_clean   (GdaSqlTable *table);
 
 void             gda_sql_table_take_name      (GdaSqlTable *table, GValue *value);
 
@@ -107,8 +121,9 @@ struct _GdaSqlFunction {
 	gchar              *function_name;
 	GSList             *args_list;
 
-	/* validity check with a connection */
-	gpointer            validity_meta_function; /* to be replaced with a pointer to a structure representing a DBMS data type in GdaMetaStruct */
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlFunction  *gda_sql_function_new            (GdaSqlAnyPart *parent);
@@ -162,6 +177,10 @@ struct _GdaSqlOperation {
 	GdaSqlAnyPart       any;
 	GdaSqlOperatorType  operator_type;
 	GSList             *operands;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlOperation  *gda_sql_operation_new            (GdaSqlAnyPart *parent);
@@ -181,6 +200,10 @@ struct _GdaSqlCase
 	GSList          *when_expr_list;
 	GSList          *then_expr_list;
 	GdaSqlExpr      *else_expr;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlCase        *gda_sql_case_new            (GdaSqlAnyPart *parent);
@@ -202,13 +225,17 @@ struct _GdaSqlSelectField
 	/* validity check with a connection */
 	GdaMetaDbObject    *validity_meta_object;
 	GdaMetaTableColumn *validity_meta_table_column;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlSelectField *gda_sql_select_field_new            (GdaSqlAnyPart *parent);
 void               gda_sql_select_field_free           (GdaSqlSelectField *field);
 GdaSqlSelectField *gda_sql_select_field_copy           (GdaSqlSelectField *field);
 gchar             *gda_sql_select_field_serialize      (GdaSqlSelectField *field);
-void               gda_sql_select_field_check_clean    (GdaSqlSelectField *field);
+void               _gda_sql_select_field_check_clean   (GdaSqlSelectField *field);
 
 void               gda_sql_select_field_take_star_value(GdaSqlSelectField *field, GValue *value);
 void               gda_sql_select_field_take_expr      (GdaSqlSelectField *field, GdaSqlExpr *expr);
@@ -226,13 +253,17 @@ struct _GdaSqlSelectTarget
 
 	/* validity check with a connection */
 	GdaMetaDbObject    *validity_meta_object;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlSelectTarget *gda_sql_select_target_new            (GdaSqlAnyPart *parent);
 void                gda_sql_select_target_free           (GdaSqlSelectTarget *target);
 GdaSqlSelectTarget *gda_sql_select_target_copy           (GdaSqlSelectTarget *target);
 gchar              *gda_sql_select_target_serialize      (GdaSqlSelectTarget *target);
-void                gda_sql_select_target_check_clean    (GdaSqlSelectTarget *target);
+void                _gda_sql_select_target_check_clean   (GdaSqlSelectTarget *target);
 
 void                gda_sql_select_target_take_table_name (GdaSqlSelectTarget *target, GValue *value);
 void                gda_sql_select_target_take_select (GdaSqlSelectTarget *target, GdaSqlStatement *stmt);
@@ -256,6 +287,10 @@ struct _GdaSqlSelectJoin
 	gint                  position; /* between a target at (pos < @position) and the one @position */
 	GdaSqlExpr           *expr;
 	GSList               *use;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlSelectJoin  *gda_sql_select_join_new            (GdaSqlAnyPart *parent);
@@ -274,6 +309,10 @@ struct _GdaSqlSelectFrom
 	GdaSqlAnyPart    any;
 	GSList          *targets; 
 	GSList          *joins; 
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlSelectFrom  *gda_sql_select_from_new            (GdaSqlAnyPart *parent);
@@ -293,6 +332,10 @@ struct _GdaSqlSelectOrder
 	GdaSqlExpr      *expr; 
 	gboolean         asc;
 	gchar           *collation_name;
+
+	/* Padding for future expansion */
+	gpointer         _gda_reserved1;
+	gpointer         _gda_reserved2;
 };
 
 GdaSqlSelectOrder *gda_sql_select_order_new            (GdaSqlAnyPart *parent);
