@@ -115,7 +115,7 @@ test2 (GError **error)
 
 	h = gda_set_get_holder (set, "H1");
 	if (!h) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "Could not find GdaHolder H1");
 		return FALSE;
 	}
@@ -174,7 +174,7 @@ t3_validate_holder_change (GdaSet *set, GdaHolder *h, const GValue *value, gchar
 			GError *error = NULL;
 			g_print ("GdaHolder change refused\n");
 			g_set_error (&error, 0, 0,
-				     "GdaHolder change refused!");
+				     "%s", "GdaHolder change refused!");
 			return error;
 		}
 	}
@@ -203,13 +203,13 @@ test3 (GError **error)
 	h = gda_set_get_holder (set, "H2");
 	g_value_set_int ((value = gda_value_new (G_TYPE_INT)), 333);
 	if (gda_holder_set_value (h, value, &lerror)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "gda_holder_set_value() should have been refused and failed");
 		return FALSE;
 	}
 	gda_value_free (value);
 	if (!lerror) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "Returned GError should not be NULL");
 		return FALSE;
 	}
@@ -226,7 +226,7 @@ test3 (GError **error)
 	g_value_set_int ((value = gda_value_new (G_TYPE_INT)), 1234);
 	cvalue = gda_set_get_holder_value (set, "H2");
 	if (!cvalue || gda_value_differ (value, cvalue)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -239,7 +239,7 @@ test3 (GError **error)
 	
 	/***/cvalue = gda_set_get_holder_value (set, "H2");
 	if (!cvalue || gda_value_differ (value, cvalue)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -270,12 +270,12 @@ test4 (GError **error)
 
 	h = gda_set_get_holder (set, "H1");
 	if (!h) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "Could not find GdaHolder H1");
 		return FALSE;
 	}
 	g_value_set_string ((value = gda_value_new (G_TYPE_STRING)), "Hello!");
-	gda_holder_set_attribute (h, "MyAttr", value);
+	gda_holder_set_attribute_static (h, "MyAttr", value);
 	gda_value_free (value);
 
 	if (!emitted_signals_find (set, "holder-attr-changed", error))
@@ -313,7 +313,7 @@ t5_validate_change (GdaSet *set, gchar *token)
 		GError *error = NULL;
 		g_print ("GdaSet change refused\n");
 		g_set_error (&error, 0, 0,
-			     "GdaSet change refused!");
+			     "%s", "GdaSet change refused!");
 		return error;
 	}
 }
@@ -335,13 +335,13 @@ test5 (GError **error)
 			  G_CALLBACK (t5_validate_change), "MyToken2");
 
 	if (gda_set_is_valid (set, &lerror)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "gda_set_is_valid() should have returned FALSE");
 		return FALSE;
 	}
 
 	if (!lerror) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "Returned GError should not be NULL");
 		return FALSE;
 	}
@@ -358,7 +358,7 @@ test5 (GError **error)
 	h = gda_set_get_holder (set, "H2");
 	g_value_set_int ((value = gda_value_new (G_TYPE_INT)), 125);
 	if (!gda_holder_set_value (h, value, NULL)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "gda_holder_set_value() should not have failed");
 		return FALSE;
 	}
@@ -367,7 +367,7 @@ test5 (GError **error)
 	h = gda_set_get_holder (set, "H3");
 	g_value_set_char ((value = gda_value_new (G_TYPE_CHAR)), 'd');
 	if (!gda_holder_set_value (h, value, NULL)) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, 0, 0, "%s", 
 			     "gda_holder_set_value() should not have failed");
 		return FALSE;
 	}
